Crate kcr_instana_io

Crate kcr_instana_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the instana.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

instana.io/v1

  • InstanaAgent
  • InstanaAgentRemote

Modules

v1